Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/mono.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlexander Köplinger <alex.koeplinger@outlook.com>2017-05-31 04:24:19 +0300
committerAlexander Köplinger <alex.koeplinger@outlook.com>2017-05-31 04:33:45 +0300
commit84fe1a57740b465fadcc3f365b470e558a82c62e (patch)
tree2c4dbb445ae9270c7ebf5c09b07e62d0ccffedfd /packaging/MacSDK
parent819026f391e06ca29f411aa9959dbcda45d85e3a (diff)
[MacSDK] Port two msbuild fixes from private bockbuild
https://github.com/xamarin/bockbuild/commit/58467b852e13b4bdfc75a2a0f9b9507b417b0694: [msbuild] Create symlinks from lib/mono/xbuild/Microsoft/NuGet/* msbuild install script cannot do this as the source files are installed by mono, which are in a different staging directory. https://github.com/xamarin/bockbuild/commit/fb9656a7613bab2d77c8ce7e05d673c5abbbdac5: Partially Revert "[msbuild] Remove redundant msbuild logic from mono_master.py" Use 15.0 instead of mono version! msbuild's install script cannot copy these since bockbuild installs msbuild to a separate staging directory from mono. So, it needs to be done here.
Diffstat (limited to 'packaging/MacSDK')
-rw-r--r--packaging/MacSDK/mono.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/packaging/MacSDK/mono.py b/packaging/MacSDK/mono.py
index ed9de817484..34f7afe3107 100644
--- a/packaging/MacSDK/mono.py
+++ b/packaging/MacSDK/mono.py
@@ -85,16 +85,16 @@ class MonoMasterPackage(Package):
"LocalMachine")
ensure_dir(registry_dir)
# Add ImportBefore/ImportAfter files from xbuild to the msbuild
# directories
xbuild_dir = os.path.join(self.staged_prefix, 'lib/mono/xbuild')
- new_xbuild_tv_dir = os.path.join(xbuild_dir, self.version)
+ new_xbuild_tv_dir = os.path.join(xbuild_dir, '15.0')
os.makedirs(new_xbuild_tv_dir)
self.sh('cp -R %s/14.0/Imports %s' % (xbuild_dir, new_xbuild_tv_dir))
- self.sh(
- 'cp -R %s/14.0/Microsoft.Common.targets %s' %
- (xbuild_dir, new_xbuild_tv_dir))
+
+ for dep in glob.glob("%s/Microsoft/NuGet/*" % xbuild_dir):
+ self.sh('ln -s %s %s' % (dep, xbuild_dir))
def deploy(self):
if bockbuild.cmd_options.arch == 'darwin-universal':
@@ -85,16 +85,16 @@ class MonoMasterPackage(Package):
"LocalMachine")
ensure_dir(registry_dir)
- # Add ImportBefore/ImportAfter files from xbuild to the msbuild
- # directories
+ # Add ImportBefore files from xbuild 14.0 toolsVersion directory to msbuild's
+ # 15.0 directory
xbuild_dir = os.path.join(self.staged_prefix, 'lib/mono/xbuild')